@@ -6,7 +6,6 @@
 */
 
 #include "klanguagebutton.h"
-#include "kconfigwidgets_debug.h"
 
 #include <QDir>
 #include <QFile>
@@ -280,3 +279,5 @@ void KLanguageButtonPrivate::setCurrentItem(QAction *a)
         button->setText(a->text());
     }
 }
+
+#include "moc_klanguagebutton.cpp"
